<!DOCTYPE html>
<html>
  <head>
    <meta http-equiv="content-type" content="text/html; charset=utf-8">
    <title>Example site</title>
  </head>
  <body>
    {% block "content" %}{% endblock %}
  </body>
</html>
