{% load i18n %}

{% for error in form.non_field_errors %}
  <p class="error">{{ error }}</p>
{% endfor %}

<div class="auth_form">
  <form action="" method="post">
    {% csrf_token %}
    {% include "authens/form_snippet.html" %}

    <input type="submit" value="{% trans submit_text %}">
  </form>
</div>
