{% extends "example/base.html" %}

{% block "content" %}
  <h2>This page is protected</h2>
  <p>You are logged in as {{ user }}</p>
  <p><a href="{% url "authens:logout" %}">Log out</a></p>
{% endblock %}
